==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/SplineFragmentBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineSeriesBaseDescriptionMetadata } from "./SplineSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
export let SplineFragmentBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class SplineFragmentBaseDescriptionMetadata extends Base {
        static b(a) {
            if (SplineFragmentBaseDescriptionMetadata.a == null) {
                SplineFragmentBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SplineFragmentBaseDescriptionMetadata.c(SplineFragmentBaseDescriptionMetadata.a);
            }
            if (a.j(SplineFragmentBaseDescriptionMetadata.a)) {
                return;
            }
            a.y(SplineFragmentBaseDescriptionMetadata.a);
        }
        static c(a) {
            SplineSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            SplineFragmentBaseDescriptionMetadata.b(a);
            a.z("SplineFragmentBase", SplineFragmentBaseDescriptionMetadata.a);
        }
    }
    SplineFragmentBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(SplineFragmentBaseDescriptionMetadata, 'SplineFragmentBaseDescriptionMetadata');
    SplineFragmentBaseDescriptionMetadata.a = null;
    return SplineFragmentBaseDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/SplineFragmentBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineSeriesBaseDescriptionMetadata } from "./SplineSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
export let SplineFragmentBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class SplineFragmentBaseDescriptionMetadata extends Base {
        static b(a) {
            if (SplineFragmentBaseDescriptionMetadata.a == null) {
                SplineFragmentBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SplineFragmentBaseDescriptionMetadata.c(SplineFragmentBaseDescriptionMetadata.a);
            }
            if (a.k(SplineFragmentBaseDescriptionMetadata.a)) {
                return;
            }
            a.aa(SplineFragmentBaseDescriptionMetadata.a);
        }
        static c(a) {
            SplineSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            SplineFragmentBaseDescriptionMetadata.b(a);
            a.ab("SplineFragmentBase", SplineFragmentBaseDescriptionMetadata.a);
        }
    }
    SplineFragmentBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(SplineFragmentBaseDescriptionMetadata, 'SplineFragmentBaseDescriptionMetadata');
    SplineFragmentBaseDescriptionMetadata.a = null;
    return SplineFragmentBaseDescriptionMetadata;
})();
